@@ -7,25 +7,43 @@ factorize.default <- Relevel.default
 # The Lexis version of this
   Relevel.Lexis <-
 factorize.Lexis <-
-function (x, states=NULL, print=TRUE, ...)
+function (x, states=NULL, print=TRUE, ... )
 {
 # Is this really a Lexis object
 if( !inherits(x,"Lexis") ) stop( "First argument must be a Lexis object" )
 
-# Make the state variables into factors with the same levels set
+# If lex.Cst and lex.Xst are not factors, make them:
+if( !is.factor(x$lex.Cst) | !is.factor(x$lex.Xst) )
+  {
 Cst <- factor(x$lex.Cst)
 Xst <- factor(x$lex.Xst)
+  }
+else # just use the factors as they are
+  {
+Cst <- x$lex.Cst
+Xst <- x$lex.Xst
+  }
+# - but amend them to have the same set of levels
 all.levels = union(levels(Cst), levels(Xst))
 Cst <- factor(Cst, levels = all.levels)
 Xst <- factor(Xst, levels = all.levels)
-x$lex.Cst <- Cst
-x$lex.Xst <- Xst
+
+# A table of actually occurring levels and their names
+tCX <- table(Cst) + table(Xst)
+all.levels <- names( tCX[tCX>0] )
+
+# If states are not given, just return factors with reduced levels
+if( is.null(states) )
+  {
+x$lex.Cst <- factor( Cst, levels = all.levels )
+x$lex.Xst <- factor( Xst, levels = all.levels )
+  }
 
 # If new state names are given as a list it implies merging of them
 if( !is.null( states ) & is.list( states ) )
   {
-  x$lex.Cst <- Relevel( x$lex.Cst, states, ... )
-  x$lex.Xst <- Relevel( x$lex.Xst, states, ... )
+  x$lex.Cst <- Relevel( Cst, states, ... )
+  x$lex.Xst <- Relevel( Xst, states, ... )
   if( print )
     {
     # Construct translation table between old and grouped states to print
@@ -41,19 +59,19 @@ if( !is.null( states ) & is.list( states ) )
                        new=c( apply( cC, 1, paste, collapse="" ),
                               apply( cX, 1, paste, collapse="" ) ) ) )
     }
-  return( x )
   }
 
-# If states are just given as a vector we assume that it's just new names
-if( !is.null( states ) & !is.list( states ) )
+# If states is a character vector we assume that it's just new names
+if( !is.null( states ) & is.character( states ) )
   {
   if( length( states ) != nlevels(Cst) )
     stop( "Second argument is a vector of length ", length(states),
           ", but it should be the joint no. of states, ",
          length(all.levels),
           "\ncorresponding to ", all.levels )
-  levels( x$lex.Cst ) <-
-  levels( x$lex.Xst ) <- states
+  levels( Cst ) <- levels( Xst ) <- states
+  x$lex.Cst <- Cst
+  x$lex.Xst <- Xst
   if( print )
     {
     cat( "New levels for lex.Xst and lex.Cst generated:\n" )
@@ -61,5 +79,12 @@ if( !is.null( states ) & !is.list( states ) )
     }
   }
 
+# If states is a numeric vector we assume that it's just reordering
+if( !is.null( states ) & is.numeric( states ) )
+  {
+  x$lex.Cst <- Relevel( Cst, states )
+  x$lex.Xst <- Relevel( Xst, states )
+  }
+
 return( x )
 }
